#ifndef ALGORITHM_H_
#define ALGORITHM_H_

#include "Choice.h"

class Engine;

/**
 * Algorithm for making choices and predictions.
 */
class Algorithm
{
public:
    Algorithm()
        : engine(NULL), choice(Choice::NONE), prediction(Choice::NONE) {}
    virtual ~Algorithm() {}

    /**
     * Set the game engine.
     * @param eng the engine.
     */
    void set_engine(Engine *eng) { engine = eng; }

    /**
     * Get the chosen choice choice.
     * @return the predicted choice.
     */
    Choice get_choice() const { return choice; }

    /**
     * Get the predicted choice.
     * @return the predicted choice.
     */
    Choice get_prediction() const { return prediction; }

    /**
     * Template method:
     * To choose, first predict, then decide.
     * @return the chosen choice.
     */
    Choice choose()
    {
        prediction = predict();
        choice = decide(prediction);

        return choice;
    }

protected:
    Engine *engine;     // the game engine
    Choice choice;      // chosen choice
    Choice prediction;  // predicted choice

    /**
     * Make a prediction depending on the algorithm.
     * @return the predicted choice.
     *         Default is NONE (no prediction)
     */
    virtual Choice predict() { return Choice::NONE; }

    /**
     * Decide on a choice depending on a prediction and the algorithm.
     * @param prediction the prediction.
     * @return the decided choice.
     */
    virtual Choice decide(const Choice prediction) = 0;
};

#endif /* ALGORITHM_H_ */
