#ifndef DISPLAY_H_
#define DISPLAY_H_

#include "Choice.h"
#include "Who.h"

class Display
{
public:
    Display() {}
    virtual ~Display() {}

    /**
     * Show the start of a game.
     */
    virtual void show_game_start() const {};

    /**
     * Show the end of a game.
     * @param human_wins the number of human wins.
     * @param computer_wins the number of computer wins.
     * @param ties the number of ties.
     * @param max_rounds the max number of rounds per game.
     */
    virtual void show_game_end(const int human_wins,
                               const int computer_wins,
                               const int ties,
                               const int max_rounds) const {}

    /**
     * Show the number of the current round.
     */
    virtual void show_round(const int round) const {};

    /**
     * Update the display.
     * @param human_choice the human's choice.
     * @param computer_choice the computer's choice.
     * @param predicted_choice the predicted choice.
     * @param winner the winner of the round.
     * @param human_wins the number of human wins.
     * @param computer_wins the number of computer wins.
     * @param ties the number of ties.
     */
    virtual void update(const Choice human_choice,
                        const Choice computer_choice,
                        const Choice predicted_choice,
                        const Who winner,
                        const int human_wins,
                        const int computer_wins,
                        const int ties) const {}
};

#endif /* DISPLAY_H_ */
