#ifndef GUIDISPLAY_H
#define GUIDISPLAY_H

#include "Display.h"

class RPS;

class GUIDisplay : public Display
{
public:
    GUIDisplay(RPS *r) : rps(r) {}
    virtual ~GUIDisplay() {}

    /**
     * Show the number of the current round.
     */
    virtual void show_game_start() const override;

    /**
     * Show the end of a game.
     * @param human_wins the number of human wins.
     * @param computer_wins the number of computer wins.
     * @param ties the number of ties.
     * @param max_rounds the max number of rounds per game.
     */
    virtual void show_game_end(const int human_wins,
                               const int computer_wins,
                               const int ties,
                               const int max_rounds) const override;

    /**
     * Show the number of the current round.
     */
    virtual void show_round(const int round) const override;

    /**
     * Update the display.
     * @param human_choice the human's choice.
     * @param computer_choice the computer's choice.
     * @param predicted_choice the predicted choice.
     * @param winner the winner of the round.
     * @param human_wins the number of human wins.
     * @param computer_wins the number of computer wins.
     * @param ties the number of ties.
     */
    virtual void update(const Choice human_choice,
                        const Choice computer_choice,
                        const Choice predicted_choice,
                        const Who winner,
                        const int human_wins,
                        const int computer_wins,
                        const int ties) const override;

private:
    RPS *rps;
};

#endif // GUIDISPLAY_H
